@@ -23,29 +23,31 @@ import queue
 import json
 import os
 
-def eval_cost(x, i, step_param_names, step_objfunc, calib_params, req_queue, files, url, param, conf: Dict, r, s):
-    no_particles = len(x[:, 0])
 
-    pfail_count = conf.get('particles_fail', 1)   # Number of particles allowed to fail.
+def eval_cost(x, iteration, step_param_names, step_objfunc, calib_params, req_queue, files, url, param, conf: Dict, rnd,
+              step):
+    particles = len(x[:, 0])
+
+    pfail_count = conf.get('particles_fail', 1)  # Number of particles allowed to fail.
     pfail_retry = conf.get('particles_retry', 3)  # retry number of times if more than allowed fail
 
     while pfail_retry > 0:
-        cost = np.ones(no_particles)
+        cost = np.ones(particles)
         res_queue = queue.Queue()
 
         print('   ', end='', flush=True)
 
         # submit for processing
         # for i_particle, v in enumerate(x[:, 0]):
-        for i_particle in range(no_particles):
-            req_queue.put((r, s, i, i_particle, x, step_param_names, calib_params, step_objfunc, res_queue))
+        for particle in range(particles):
+            req_queue.put((rnd, step, iteration, particle, x, step_param_names, calib_params, step_objfunc, res_queue))
             # req_queue.put((i_particle, x[i_particle,:], step_param_names, calib_params, step_objfunc, res_queue))
 
         # wait for the cost value to come back
         # for i, v in enumerate(x[:, 0]):
-        for i in range(no_particles):
-            (i_particle, p_cost) = res_queue.get()
-            cost[i_particle] = p_cost
+        for idx in range(particles):
+            (particle, p_cost) = res_queue.get()
+            cost[particle] = p_cost
             res_queue.task_done()
 
         res_queue.join()
@@ -60,7 +62,7 @@ def eval_cost(x, i, step_param_names, step_objfunc, calib_params, req_queue, fil
         # leave the loop if fails acceptable
         if failed_particles <= pfail_count:
             break
-        print("Re-running particles, since ", failed_particles, ' out of ', no_particles,' particles failed.')
+        print("Re-running particles, since ", failed_particles, ' out of ', particles, ' particles failed.')
         pfail_retry -= 1
 
     if pfail_retry == 0:
@@ -75,10 +77,11 @@ def eval_cost(x, i, step_param_names, step_objfunc, calib_params, req_queue, fil
     print(flush=True)
     return cost
 
+
 def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters: int, options: Dict,
                 oh_strategy: Dict = None, n_threads: int = 4, rtol: float = 0.001, ftol: float = -np.inf,
                 ftol_iter: int = 1, full_trace: List = None, rtol_iter: int = 1,
-                conf: Dict = None, metainfo: Dict = None, cost_target:float = -np.inf) -> Tuple:
+                conf: Dict = None, metainfo: Dict = None, cost_target: float = -np.inf) -> Tuple:
     """Performs a stepwise particle swarm optimization PSO using a global best approach.
 
         Parameters
@@ -174,12 +177,12 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
     step_trace['steps'] = copy.deepcopy(steps)
     step_trace['args'] = args
 
-    if step_file is not None :
+    if step_file is not None:
         with open(step_file, "w") as fo:
             json.dump(step_trace, fo)
 
     # best round cost
-    best_round_cost =  np.inf
+    best_round_cost = np.inf
 
     # request queue for worker
     req_queue = queue.Queue()
@@ -231,8 +234,8 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
             print('\n>>>>> R{}/S{}  particle params: {}  calibrated params: {}\n'.format(r + 1, s + 1, param_names,
                                                                                          args['calib_params']))
 
-            args['r'] = r+1
-            args['s'] = s+1
+            args['rnd'] = r + 1
+            args['step'] = s + 1
 
             # perform optimization
             cost, pos = optimizer[s].optimize(eval_cost,
@@ -253,11 +256,11 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
 
             key = "r{}s{}".format(r + 1, s + 1)
             step_trace[key] = {}
-            step_trace[key]['time'] =  str(datetime.datetime.now())
+            step_trace[key]['time'] = str(datetime.datetime.now())
             step_trace[key]['best_costs'] = best_cost
             step_trace[key]['steps'] = copy.deepcopy(steps)
 
-            if step_file is not None :
+            if step_file is not None:
                 with open(step_file, "w") as fo:
                     json.dump(step_trace, fo)
 
@@ -285,7 +288,7 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
         step_trace[key]['round_cost'] = round_cost
         step_trace[key]['best_costs'] = best_cost
         step_trace[key]['improvements'] = no_improvement
-        if step_file is not None :
+        if step_file is not None:
             with open(step_file, "w") as fo:
                 json.dump(step_trace, fo)
 
@@ -313,13 +316,12 @@ def global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters:
     step_trace['end'] = str(datetime.datetime.now())
     step_trace['time'] = elapsed
 
-    if step_file is not None :
+    if step_file is not None:
         with open(step_file, "w") as fo:
             json.dump(step_trace, fo)
 
     return optimizer, step_trace
 
-
 # def p_global_best(steps: Dict, rounds: Tuple, args: Dict, n_particles: int, iters: int, options: Dict,
 #                   n_threads: int = 4, rtol: float = 0.001, ftol: float = -np.inf,
 #                   full_trace: List = None, rounds_below: int = 1) -> Tuple:
